pub struct UrlShortHash(/* private fields */);Expand description
This type contains the first half of a UrlHash instance where a less secure test using a
truncated hash value is acceptable.
Implementations
Sourceimpl UrlShortHash
impl UrlShortHash
Sourcepub fn very_short(&self) -> UrlVeryShortHash
pub fn very_short(&self) -> UrlVeryShortHash
Return a UrlVeryShortHash instance containing only the first value of this short hash.
Sourcepub fn starts_with(&self, very_short_hash: &UrlVeryShortHash) -> bool
pub fn starts_with(&self, very_short_hash: &UrlVeryShortHash) -> bool
Does this hash start with the value in the provided very-short hash?